<?php

$lib_common = '../../../lib-common.php';
include($lib_common);

// Only let admin users access this page
if (!SEC_inGroup('Root')) {    
// Someone is trying to illegally access this page
    COM_errorLog("Someone has tried to illegally access the Weather plugin install documentation.  User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR",1);
    $display = COM_siteHeader();
    $display .= COM_startBlock($LANG_GW00['access_denied']);
    $display .= $LANG_GW00['access_denied_msg'];
    $display .= COM_endBlock();
    $display .= COM_siteFooter(true);
    echo $display;
    exit;
}


function flush_metar($station, $new) {
  /*
   * Fetches a new METER from weather.noaa.gov. If the $new variable
   * is true, the metar is inserted, else it will replace the old
   * metar. The new METAR is returned.
   */
  global $_TABLES, $useProxy, $proxy_host, $proxy_port;
    
    
  $metar = '';
  $station = strtoupper($station);
  
  if ($useProxy) {
    /* Inspirated by code from Paul Kairis <Paul.Kairis@sas.com> */
    
    $fp = fsockopen($proxy_host, $proxy_port); // connect to proxy
    if ($fp) {
      fputs($fp, 'GET http://weather.noaa.gov/pub/data/' .
            "observations/metar/stations/$station.TXT HTTP/1.0\r\n" .
            "If-Modified-Since: Sat, 29 Oct 1994 09:00:00 GMT\r\n" .
            "Pragma: no-cache\r\n\r\n"); 
      
      /* We check the status line */
      if (strpos(fgets($fp, 1024), '200')) {
        /* Then we seek until we find the empty line between the
           header and the contents. */
        $line = fgets($fp, 1024);
        while ($line != "\r\n") {
          $line = fgets($fp, 1024);
        }
        /* We now know, that the following lines are the contents. */
        unset($file);
        while ($line = fgets($fp, 1024)) {
          $file[] = $line;
        }
        fclose($fp);
      }
    }
  } else {
    /* We use the @ notation, because it might fail. */
    $file  = @file('http://weather.noaa.gov/pub/data/' .
                   "observations/metar/stations/$station.TXT");
  }

  /* Here we test to see if we actually got a METAR. */
  if (is_array($file)) {
    $date = trim($file[0]);
    $metar = trim($file[1]);
    for ($i = 2; $i < count($file); $i++) {
      $metar .= ' ' . trim($file[$i]);
    }
    
    /* The date is in the form 2000/10/09 14:50 UTC. This seperates
       the different parts. */
    $date_parts = explode(':', strtr($date, '/ ', '::'));
    $date_unixtime = gmmktime($date_parts[3], $date_parts[4],
                              0, $date_parts[1], $date_parts[2],
                              $date_parts[0]);
   
    if (!ereg('[0-9]{6}Z', $metar)) {
      /* Some reports dont even have a time-part, so we insert the
       * current time. This might not be the time of the report, but
       * it was broken anyway :-) */
      $metar = gmdate('dHi', $date_unixtime) . 'Z ' . $metar;
    }
    
    if ($date_unixtime < (time() - 3300)) {
      /* The timestamp in the metar is more than 55 minutes old. We
       * adjust the timestamp, so that we won't try to fetch a new
       * METAR within the next 5 minutes. After 5 minutes, the
       * timestamp will again be more than 1 hour old. */
      $date_unixtime = time() - 3300;
    }

  } else {
    /* If we end up here, it means that there was no file, we then set
     * the metar to and empty string. We set the date to time() - 3000
     * to give the server 10 minutes of peace. If the file is
     * unavailable, we don't want to stress the server. */
    $metar = '';
    $date_unixtime = time() - 3000;
  }
  
  /* It might seam strange, that we make a local date, but MySQL
   * expects a local when we insert the METAR. */
  $date = date('Y/m/d H:i', $date_unixtime);


    if ($new==1) {         	
      /* Insert the new record */
      $query = "INSERT INTO {$_TABLES['weather_cache']} SET station = '$station', " .
         "metar = '$metar', timestamp = '$date'";
    }
    if ($new==0) {
      /* Update the old record */
     $query = "UPDATE {$_TABLES['weather_cache']} SET metar = '$metar', " .
         "timestamp = '$date' WHERE station = '$station'";            
    }
    DB_query($query);    
    
  return $metar;
}

function update_metars_db() {
  /* Updates all the metars in the database. You should use it like
   * this:
   
   * This will update all the metars *after* the script has
   * finished. This means that the user won't know that PHP is still
   * running, and most important, they won't have to wait when the
   * script fetches a new METAR, because it is done afterwards.
   */

  //include('config.inc');

  global $_TABLES;
  
    $query = "SELECT station FROM {$_TABLES['weather_cache']}";
    $result = DB_query($query);
    while (list($station) = DB_fetchArray($result)) {
      flush_metar($station, 0);
    }
}

$display .= COM_siteHeader('menu');
$display .= COM_startBlock('Weather Adminstration');
//register_shutdown_function('update_metars_db');
update_metars_db();
$display .= "Cache Flush Complete!";
$display .= COM_endBlock();               
$display .= COM_siteFooter(true);
echo $display;
echo COM_refresh('index.php');
?>